@@ -1,10 +1,10 @@
 # SPDX-License-Identifier: MIT
 # Copyright (C) 2022 Max Bachmann
 
-from rapidfuzz.utils import _fallback_import
+from rapidfuzz._utils import fallback_import as _fallback_import
 
 _mod = "rapidfuzz.process"
 extract = _fallback_import(_mod, "extract")
 extractOne = _fallback_import(_mod, "extractOne")
 extract_iter = _fallback_import(_mod, "extract_iter")
-cdist = _fallback_import("rapidfuzz.process_cdist", "cdist")
+cdist = _fallback_import(_mod, "cdist")
